@@ -1,4 +1,4 @@
-__version__ = '0.1.20'
+__version__ = '0.1.21'
 
 PID_FILE = '/tmp/yedb-server.pid'
 
@@ -69,8 +69,8 @@ METHODS = [
     'test', 'key_get', 'key_set', 'key_list', 'key_list_all',
     'key_get_recursive', 'key_copy', 'key_rename', 'key_exists', 'key_explain',
     'key_delete', 'key_delete_recursive', 'purge', 'check', 'repair', 'info',
-    'key_dump', 'key_load', 'key_update', 'safe_purge', 'server_set',
-    'key_increment', 'key_decrement'
+    'key_dump', 'key_load', 'key_update', 'safe_purge', 'purge_cache',
+    'server_set', 'key_increment', 'key_decrement'
 ]
 
 
